import logging

import typer

from citadel.mqtt import Client

from . import Light, LightsGroup

import systemd.journal

def main(\
        mqtt_user: str = typer.Option(... , envvar="DEVICES_MQTT_USER"),\
        mqtt_pwd: str = typer.Option(... ,  envvar="DEVICES_MQTT_PWD"),\
        mqtt_host: str = typer.Option(... , envvar="DEVICES_MQTT_HOST"),\
        mqtt_port: int = typer.Option(... , envvar="DEVICES_MQTT_PORT"),\
        is_systemd: bool = typer.Option(False, help="Is running as systemd unit", envvar="LAUNCHED_BY_SYSTEMD")\
        ):

    client = Client()
    client.setup(mqtt_host, mqtt_port, mqtt_user, mqtt_pwd)

    lights1 = LightsGroup('KitchenLed',
            client, [Light('KitchenCeiling1', client,
                    STATE_TOPIC='stat/tasmota/light/{id}/POWER1',
                    CMND_TOPIC='cmnd/tasmota/light/{id}/POWER1'),
                Light('KitchenCeiling2', client,
                    STATE_TOPIC='stat/tasmota/light/{id}/POWER1',
                    CMND_TOPIC='cmnd/tasmota/light/{id}/POWER1')])

    lights2 = LightsGroup('KitchenCelling',
            client, [
                Light('KitchenCeiling1', client,
                    STATE_TOPIC='stat/tasmota/light/{id}/POWER2',
                    CMND_TOPIC='cmnd/tasmota/light/{id}/POWER2'),
                Light('KitchenCeiling2', client,
                    STATE_TOPIC='stat/tasmota/light/{id}/POWER2',
                    CMND_TOPIC='cmnd/tasmota/light/{id}/POWER2')])


    if is_systemd:
        logger = logging.getLogger('')
        logger.setLevel(logging.DEBUG)
        logger.addHandler(systemd.journal.JournalHandler())
    else:
        logger = logging.getLogger('')
        logger.setLevel(logging.DEBUG)
        # create console handler and set level to debug
        ch = logging.StreamHandler()
        ch.setLevel(logging.DEBUG)
        # create formatter
        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
        # add formatter to ch
        ch.setFormatter(formatter)
        # add ch to logger
        logger.addHandler(ch)

    client.loop_forever()

if __name__ == "__main__":
    typer.run(main)
